Improve this Doc

# `ngSanitize`

## Installation

First, get the file:

- Google CDN e.g.

      "//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-sanitize.js"

- NPM e.g.

      npm install --save angular-sanitize@X.Y.Z

  or

      yarn add angular-sanitize@X.Y.Z

- Bower e.g.

      bower install angular-sanitize#X.Y.Z

- code.angularjs.org (discouraged for production use) e.g.

      "//code.angularjs.org/X.Y.Z/angular-sanitize.js"

where X.Y.Z is the AngularJS version you are running.

Then, include `angular-sanitize.js` in your HTML:

    <script src="path/to/angular.js"></script>
    <script src="path/to/angular-sanitize.js"></script>

Finally, load the module in your application by adding it as a dependent module:

    angular.module('app', ['ngSanitize']);

With that you're ready to get started!

# ngSanitize

The `ngSanitize` module provides functionality to sanitize HTML.

See `$sanitize` for usage.

## Module Components

### Filter

Name | Description
--- | ---
linky | Finds links in text input and turns them into html links. Supports `http/https/ftp/mailto` and plain email address links.

### Service

Name | Description
--- | ---
$sanitize | Sanitizes an html string by stripping all potentially dangerous tokens.

### Provider

Name | Description
--- | ---
$sanitizeProvider | Creates and configures `$sanitize` instance.